@@ -3,7 +3,7 @@
 
 CURRYBIN="../../../bin"
 
-ALLTESTS="DefaultRulesTest DetOperations ExampleTests ExamplesFromManual ListSpecifications Nats SEBF Sum SortSpec Tree"
+ALLTESTS="DefaultRulesTest DetOperations ExampleTests ExamplesFromManual FloatTest ListSpecifications Nats SEBF Sum SortSpec Tree"
 
 VERBOSE=no
 if [ "$1" = "-v" ] ; then
